#
# spec file for package python-SPARQLWrapper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-SPARQLWrapper
Version:        2.0.0
Release:        1.7
Summary:        SPARQL Endpoint interface to Python
License:        W3C
URL:            https://rdflib.dev/sparqlwrapper/
Source:         https://files.pythonhosted.org/packages/source/S/SPARQLWrapper/SPARQLWrapper-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-rdflib >= 4.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is a wrapper around a SPARQL service. It helps in creating the
query URI and, possibly, convert the result into a more manageable
format.

%prep
%setup -q -n SPARQLWrapper-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/rqw
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
#%%pytest test

%post
%python_install_alternative rqw

%postun
%python_uninstall_alternative rqw

%files %{python_files}
%license LICENSE.txt
%doc README.rst AUTHORS.md
%python_alternative %{_bindir}/rqw
%{python_sitelib}/SPARQLWrapper
%{python_sitelib}/SPARQLWrapper-%{version}.dist-info

%changelog
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * Ported codebase to Python 3. Dropped support for Python 2
  * Removed nosetest in favour of unittest
  * Added a CLI: ``rqw``
  * Updated for RDFLib >= 6.1.1
  * Added type hints
- drop no-2to3.patch (obsolete)
* Mon Mar  7 2022 Dirk Müller <dmueller@suse.com>
- add no-2to3.patch for better compatibility with newer setuptools
* Wed Mar 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests as they need quite lot of magic to run just on py3
* Wed Mar 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.5:
  - Improve/tests for development (#131)
  - Changed. Be more strict on Accept Turtle header (#137)
  - Migrated documentation from epydoc to sphinx and readthedocs
  - Include ChangeLog.txt in the distribution
  - Removed import of SPARQLWrapper in setup.py (fixed #113 and closed #115)
  - Added support for querying RDF/XML in a CONSTRUCT query type
  - Updated the procedure for determining the query type (#120)
  - Do not send format parameter for the results ([format, output, results]) when the query is a SPARQL Update query
  - Added test for new agrovoc SPARQL endpoint (using Fuseki2)
  - Added test for 4store SPARQL endpoint (used by agroportal)
  - Added/Updated tests
  - Added examples
  - Updated doc
  - Fixed code generated for python3 using 2to3, adding a custom fixer (#109)
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Sun Jul  8 2018 arun@gmx.de
- specfile:
  * update tests
- update to version 1.8.2:
  * Fixed bug (#100)
  * Updated doc
  * Added Unauthorized exception in SPARQLWrapperExceptions
  * Added support for custom HTTP headers (#52)
  * Changed timeout setting (#106)
- changes from version 1.8.1:
  * Update classifiers (Python 3.6)
  * Added some documentation about the parameter to indicate the
    output format
  * Fixed typo in width calculation
  * Added support for CSV, TSV (PR #98)
  * Added support for Only HTTP Content Negotiation (#82)
* Wed Jan  3 2018 tchvatal@suse.com
- Make sure to not bail out when building with py3 only
- Do not recommend already required package
* Mon May  8 2017 toddrme2178@gmail.com
- Fix source URL.
* Wed May  3 2017 toddrme2178@gmail.com
- Update to version 1.8.0
  * Updated return formats for not content negotiation situations
  * Included license in the MANIFEST (issue #76)
  * Added explicit support for RDF/XML as allowed format (issue #75)
  * Added proper shebang (issue #78)
  * Moved keepalive as optional dependency (issue #79)
  * Fixed hash check on prefixes (issue #77)
- Fixed epydoc warnings (issue #41)
- Implement single-spec version.
- Fix source URL.
* Mon Sep 12 2016 aplanas@suse.com
- update to version 1.7.6
  * Removed wrong response encoding (issue #70)
  * Authorization header bug when using Python 3 (issue #71)
- additional changes from version 1.7.5
  * Removed pip dependency on setup (issue #69)
- additional changes from version 1.7.4
  * Fixed packaging (issue #66)
- additional changes from version 1.7.3
  * Finally fixed the keepalive issue in all Pyhon versions (issue #65)
  * Removed old JSON layer in favor of the native json module
- additional changes from version 1.7.2
  * Moved to the new keepalive package (issues #53 and #61)
- additional changes from version 1.7.1
  * Fixed build in Python 3.x (issue #57)
- additional changes from version 1.7.0
  * Added support to HTTP Digest Auth Support (issue #45)
  * Improved print_results showing language tag (xml:lang) and datatype
  * Updated to RDFLib 4.x
* Fri Feb 12 2016 olaf@aepfle.de
- Remove BuildRequires python-rdflib to avoid cirular dependency
* Wed May 13 2015 benoit.monin@gmx.fr
- update to version 1.6.4:
  * Fixed unicode problems on setup (issue #42)
- additional changes from version 1.6.3:
  * Fixed unicode problems with urllib in Python 3 (issue #35)
  * Restored SPARQLWrapper2 class (issue #36)
  * Enhanced warning for missing rdflib-jsonld (issue #38)
  * Fixed build system (issue #39)
- additional changes from version 1.6.2:
  * Fixed query type detection with comments (issue #32)
- additional changes from version 1.6.1:
  * Added missing query types (issue #17)
  * Added a new method to the API to select the request method to
    be fully SPARQL 1.1 Protocol compliant (issue #28)
  * Improved the test suite coverage, including support to run the
    tests under Python 3.x (issues #20, #24 and #31)
- additional changes from version 1.6.0:
  * Returning raw response in case of unknown content type returned
  * Fixed some issues with the last version of the SPARQL 1.1
    Update Protocol
  * setQuery() doesn't imply resetQuery() anymore
  * Deprecated addCustomParameter(), addParameter() and
    clearParameter() come to provide all required functionality
  * SPARQLWrapper, QueryResult, Value, Bindings (and classes
    inherited from them) are new-style classes now
  * POST queries are accompanied by full set of parameters now
  * Added rudimentary support for JSON-LD
  * Added proper unit tests without dependencies of external
    endpoints
  * Fixed Python 3 compatibility issues in SmartWrapper module
- require python-rdflib instead of recommending it
- require python-simplejson for SLE11
- add runtime dependencies as build dependencies
- remove the fix of end-of-line encoding: changed upstream
- run the tests during build with wrapper_test.py
- change the documentation files to follow upstream
* Fri Dec  6 2013 toddrme2178@gmail.com
- Initial version (1.5.2)
